# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchContext(object):
    """
    Contains search context, such as highlighting, for found resources.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SearchContext object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param highlights:
            The value to assign to the highlights property of this SearchContext.
        :type highlights: dict(str, list[str])

        """
        self.swagger_types = {
            'highlights': 'dict(str, list[str])'
        }

        self.attribute_map = {
            'highlights': 'highlights'
        }

        self._highlights = None

    @property
    def highlights(self):
        """
        Gets the highlights of this SearchContext.
        Describes what in each field matched the search criteria by showing highlighted values, but only for free text searches or for structured
        queries that use a MATCHING clause. The list of strings represents fragments of values that matched the query conditions. Highlighted
        values are wrapped with &lt;h1&gt;..&lt;/h1&gt; tags. All values are HTML-encoded (except &lt;h1&gt; tags).


        :return: The highlights of this SearchContext.
        :rtype: dict(str, list[str])
        """
        return self._highlights

    @highlights.setter
    def highlights(self, highlights):
        """
        Sets the highlights of this SearchContext.
        Describes what in each field matched the search criteria by showing highlighted values, but only for free text searches or for structured
        queries that use a MATCHING clause. The list of strings represents fragments of values that matched the query conditions. Highlighted
        values are wrapped with &lt;h1&gt;..&lt;/h1&gt; tags. All values are HTML-encoded (except &lt;h1&gt; tags).


        :param highlights: The highlights of this SearchContext.
        :type: dict(str, list[str])
        """
        self._highlights = highlights

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectVersionSummary(object):
    """
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized,
    talk to an administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectVersionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ObjectVersionSummary.
        :type name: str

        :param size:
            The value to assign to the size property of this ObjectVersionSummary.
        :type size: int

        :param md5:
            The value to assign to the md5 property of this ObjectVersionSummary.
        :type md5: str

        :param time_created:
            The value to assign to the time_created property of this ObjectVersionSummary.
        :type time_created: datetime

        :param time_modified:
            The value to assign to the time_modified property of this ObjectVersionSummary.
        :type time_modified: datetime

        :param etag:
            The value to assign to the etag property of this ObjectVersionSummary.
        :type etag: str

        :param version_id:
            The value to assign to the version_id property of this ObjectVersionSummary.
        :type version_id: str

        :param is_delete_marker:
            The value to assign to the is_delete_marker property of this ObjectVersionSummary.
        :type is_delete_marker: bool

        """
        self.swagger_types = {
            'name': 'str',
            'size': 'int',
            'md5': 'str',
            'time_created': 'datetime',
            'time_modified': 'datetime',
            'etag': 'str',
            'version_id': 'str',
            'is_delete_marker': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'size': 'size',
            'md5': 'md5',
            'time_created': 'timeCreated',
            'time_modified': 'timeModified',
            'etag': 'etag',
            'version_id': 'versionId',
            'is_delete_marker': 'isDeleteMarker'
        }

        self._name = None
        self._size = None
        self._md5 = None
        self._time_created = None
        self._time_modified = None
        self._etag = None
        self._version_id = None
        self._is_delete_marker = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ObjectVersionSummary.
        The name of the object. Avoid entering confidential information.
        Example: test/object1.log


        :return: The name of this ObjectVersionSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ObjectVersionSummary.
        The name of the object. Avoid entering confidential information.
        Example: test/object1.log


        :param name: The name of this ObjectVersionSummary.
        :type: str
        """
        self._name = name

    @property
    def size(self):
        """
        Gets the size of this ObjectVersionSummary.
        Size of the object in bytes.


        :return: The size of this ObjectVersionSummary.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this ObjectVersionSummary.
        Size of the object in bytes.


        :param size: The size of this ObjectVersionSummary.
        :type: int
        """
        self._size = size

    @property
    def md5(self):
        """
        Gets the md5 of this ObjectVersionSummary.
        Base64-encoded MD5 hash of the object data.


        :return: The md5 of this ObjectVersionSummary.
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """
        Sets the md5 of this ObjectVersionSummary.
        Base64-encoded MD5 hash of the object data.


        :param md5: The md5 of this ObjectVersionSummary.
        :type: str
        """
        self._md5 = md5

    @property
    def time_created(self):
        """
        Gets the time_created of this ObjectVersionSummary.
        The date and time the object was created, as described in `RFC 2616`__.

        __ https://tools.ietf.org/html/rfc2616#section-14.29


        :return: The time_created of this ObjectVersionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ObjectVersionSummary.
        The date and time the object was created, as described in `RFC 2616`__.

        __ https://tools.ietf.org/html/rfc2616#section-14.29


        :param time_created: The time_created of this ObjectVersionSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_modified(self):
        """
        **[Required]** Gets the time_modified of this ObjectVersionSummary.
        The date and time the object was modified, as described in `RFC 2616`__.

        __ https://tools.ietf.org/rfc/rfc2616#section-14.29


        :return: The time_modified of this ObjectVersionSummary.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this ObjectVersionSummary.
        The date and time the object was modified, as described in `RFC 2616`__.

        __ https://tools.ietf.org/rfc/rfc2616#section-14.29


        :param time_modified: The time_modified of this ObjectVersionSummary.
        :type: datetime
        """
        self._time_modified = time_modified

    @property
    def etag(self):
        """
        Gets the etag of this ObjectVersionSummary.
        The current entity tag (ETag) for the object.


        :return: The etag of this ObjectVersionSummary.
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """
        Sets the etag of this ObjectVersionSummary.
        The current entity tag (ETag) for the object.


        :param etag: The etag of this ObjectVersionSummary.
        :type: str
        """
        self._etag = etag

    @property
    def version_id(self):
        """
        **[Required]** Gets the version_id of this ObjectVersionSummary.
        VersionId of the object.


        :return: The version_id of this ObjectVersionSummary.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this ObjectVersionSummary.
        VersionId of the object.


        :param version_id: The version_id of this ObjectVersionSummary.
        :type: str
        """
        self._version_id = version_id

    @property
    def is_delete_marker(self):
        """
        **[Required]** Gets the is_delete_marker of this ObjectVersionSummary.
        This flag will indicate if the version is deleted or not.


        :return: The is_delete_marker of this ObjectVersionSummary.
        :rtype: bool
        """
        return self._is_delete_marker

    @is_delete_marker.setter
    def is_delete_marker(self, is_delete_marker):
        """
        Sets the is_delete_marker of this ObjectVersionSummary.
        This flag will indicate if the version is deleted or not.


        :param is_delete_marker: The is_delete_marker of this ObjectVersionSummary.
        :type: bool
        """
        self._is_delete_marker = is_delete_marker

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .authentication_policy import AuthenticationPolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JwtAuthenticationPolicy(AuthenticationPolicy):
    """
    Validate a JWT token present in the header or query parameter. A valid
    policy must specify either tokenHeader or tokenQueryParam.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JwtAuthenticationPolicy object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.JwtAuthenticationPolicy.type` attribute
        of this class is ``JWT_AUTHENTICATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_anonymous_access_allowed:
            The value to assign to the is_anonymous_access_allowed property of this JwtAuthenticationPolicy.
        :type is_anonymous_access_allowed: bool

        :param type:
            The value to assign to the type property of this JwtAuthenticationPolicy.
            Allowed values for this property are: "CUSTOM_AUTHENTICATION", "JWT_AUTHENTICATION"
        :type type: str

        :param token_header:
            The value to assign to the token_header property of this JwtAuthenticationPolicy.
        :type token_header: str

        :param token_query_param:
            The value to assign to the token_query_param property of this JwtAuthenticationPolicy.
        :type token_query_param: str

        :param token_auth_scheme:
            The value to assign to the token_auth_scheme property of this JwtAuthenticationPolicy.
        :type token_auth_scheme: str

        :param issuers:
            The value to assign to the issuers property of this JwtAuthenticationPolicy.
        :type issuers: list[str]

        :param audiences:
            The value to assign to the audiences property of this JwtAuthenticationPolicy.
        :type audiences: list[str]

        :param verify_claims:
            The value to assign to the verify_claims property of this JwtAuthenticationPolicy.
        :type verify_claims: list[JsonWebTokenClaim]

        :param max_clock_skew_in_seconds:
            The value to assign to the max_clock_skew_in_seconds property of this JwtAuthenticationPolicy.
        :type max_clock_skew_in_seconds: float

        :param public_keys:
            The value to assign to the public_keys property of this JwtAuthenticationPolicy.
        :type public_keys: PublicKeySet

        """
        self.swagger_types = {
            'is_anonymous_access_allowed': 'bool',
            'type': 'str',
            'token_header': 'str',
            'token_query_param': 'str',
            'token_auth_scheme': 'str',
            'issuers': 'list[str]',
            'audiences': 'list[str]',
            'verify_claims': 'list[JsonWebTokenClaim]',
            'max_clock_skew_in_seconds': 'float',
            'public_keys': 'PublicKeySet'
        }

        self.attribute_map = {
            'is_anonymous_access_allowed': 'isAnonymousAccessAllowed',
            'type': 'type',
            'token_header': 'tokenHeader',
            'token_query_param': 'tokenQueryParam',
            'token_auth_scheme': 'tokenAuthScheme',
            'issuers': 'issuers',
            'audiences': 'audiences',
            'verify_claims': 'verifyClaims',
            'max_clock_skew_in_seconds': 'maxClockSkewInSeconds',
            'public_keys': 'publicKeys'
        }

        self._is_anonymous_access_allowed = None
        self._type = None
        self._token_header = None
        self._token_query_param = None
        self._token_auth_scheme = None
        self._issuers = None
        self._audiences = None
        self._verify_claims = None
        self._max_clock_skew_in_seconds = None
        self._public_keys = None
        self._type = 'JWT_AUTHENTICATION'

    @property
    def token_header(self):
        """
        Gets the token_header of this JwtAuthenticationPolicy.
        The name of the header containing the authentication token.


        :return: The token_header of this JwtAuthenticationPolicy.
        :rtype: str
        """
        return self._token_header

    @token_header.setter
    def token_header(self, token_header):
        """
        Sets the token_header of this JwtAuthenticationPolicy.
        The name of the header containing the authentication token.


        :param token_header: The token_header of this JwtAuthenticationPolicy.
        :type: str
        """
        self._token_header = token_header

    @property
    def token_query_param(self):
        """
        Gets the token_query_param of this JwtAuthenticationPolicy.
        The name of the query parameter containing the authentication token.


        :return: The token_query_param of this JwtAuthenticationPolicy.
        :rtype: str
        """
        return self._token_query_param

    @token_query_param.setter
    def token_query_param(self, token_query_param):
        """
        Sets the token_query_param of this JwtAuthenticationPolicy.
        The name of the query parameter containing the authentication token.


        :param token_query_param: The token_query_param of this JwtAuthenticationPolicy.
        :type: str
        """
        self._token_query_param = token_query_param

    @property
    def token_auth_scheme(self):
        """
        Gets the token_auth_scheme of this JwtAuthenticationPolicy.
        The authentication scheme that is to be used when authenticating
        the token. This must to be provided if \"tokenHeader\" is specified.


        :return: The token_auth_scheme of this JwtAuthenticationPolicy.
        :rtype: str
        """
        return self._token_auth_scheme

    @token_auth_scheme.setter
    def token_auth_scheme(self, token_auth_scheme):
        """
        Sets the token_auth_scheme of this JwtAuthenticationPolicy.
        The authentication scheme that is to be used when authenticating
        the token. This must to be provided if \"tokenHeader\" is specified.


        :param token_auth_scheme: The token_auth_scheme of this JwtAuthenticationPolicy.
        :type: str
        """
        self._token_auth_scheme = token_auth_scheme

    @property
    def issuers(self):
        """
        **[Required]** Gets the issuers of this JwtAuthenticationPolicy.
        A list of parties that could have issued the token.


        :return: The issuers of this JwtAuthenticationPolicy.
        :rtype: list[str]
        """
        return self._issuers

    @issuers.setter
    def issuers(self, issuers):
        """
        Sets the issuers of this JwtAuthenticationPolicy.
        A list of parties that could have issued the token.


        :param issuers: The issuers of this JwtAuthenticationPolicy.
        :type: list[str]
        """
        self._issuers = issuers

    @property
    def audiences(self):
        """
        **[Required]** Gets the audiences of this JwtAuthenticationPolicy.
        The list of intended recipients for the token.


        :return: The audiences of this JwtAuthenticationPolicy.
        :rtype: list[str]
        """
        return self._audiences

    @audiences.setter
    def audiences(self, audiences):
        """
        Sets the audiences of this JwtAuthenticationPolicy.
        The list of intended recipients for the token.


        :param audiences: The audiences of this JwtAuthenticationPolicy.
        :type: list[str]
        """
        self._audiences = audiences

    @property
    def verify_claims(self):
        """
        Gets the verify_claims of this JwtAuthenticationPolicy.
        A list of claims which should be validated to consider the token valid.


        :return: The verify_claims of this JwtAuthenticationPolicy.
        :rtype: list[JsonWebTokenClaim]
        """
        return self._verify_claims

    @verify_claims.setter
    def verify_claims(self, verify_claims):
        """
        Sets the verify_claims of this JwtAuthenticationPolicy.
        A list of claims which should be validated to consider the token valid.


        :param verify_claims: The verify_claims of this JwtAuthenticationPolicy.
        :type: list[JsonWebTokenClaim]
        """
        self._verify_claims = verify_claims

    @property
    def max_clock_skew_in_seconds(self):
        """
        Gets the max_clock_skew_in_seconds of this JwtAuthenticationPolicy.
        The maximum expected time difference between the system clocks
        of the token issuer and the API Gateway.


        :return: The max_clock_skew_in_seconds of this JwtAuthenticationPolicy.
        :rtype: float
        """
        return self._max_clock_skew_in_seconds

    @max_clock_skew_in_seconds.setter
    def max_clock_skew_in_seconds(self, max_clock_skew_in_seconds):
        """
        Sets the max_clock_skew_in_seconds of this JwtAuthenticationPolicy.
        The maximum expected time difference between the system clocks
        of the token issuer and the API Gateway.


        :param max_clock_skew_in_seconds: The max_clock_skew_in_seconds of this JwtAuthenticationPolicy.
        :type: float
        """
        self._max_clock_skew_in_seconds = max_clock_skew_in_seconds

    @property
    def public_keys(self):
        """
        **[Required]** Gets the public_keys of this JwtAuthenticationPolicy.

        :return: The public_keys of this JwtAuthenticationPolicy.
        :rtype: PublicKeySet
        """
        return self._public_keys

    @public_keys.setter
    def public_keys(self, public_keys):
        """
        Sets the public_keys of this JwtAuthenticationPolicy.

        :param public_keys: The public_keys of this JwtAuthenticationPolicy.
        :type: PublicKeySet
        """
        self._public_keys = public_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .network_endpoint_details import NetworkEndpointDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateEndpointDetails(NetworkEndpointDetails):
    """
    Private endpoint configuration details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateEndpointDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.analytics.models.PrivateEndpointDetails.network_endpoint_type` attribute
        of this class is ``PRIVATE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param network_endpoint_type:
            The value to assign to the network_endpoint_type property of this PrivateEndpointDetails.
            Allowed values for this property are: "PUBLIC", "PRIVATE"
        :type network_endpoint_type: str

        :param vcn_id:
            The value to assign to the vcn_id property of this PrivateEndpointDetails.
        :type vcn_id: str

        :param subnet_id:
            The value to assign to the subnet_id property of this PrivateEndpointDetails.
        :type subnet_id: str

        """
        self.swagger_types = {
            'network_endpoint_type': 'str',
            'vcn_id': 'str',
            'subnet_id': 'str'
        }

        self.attribute_map = {
            'network_endpoint_type': 'networkEndpointType',
            'vcn_id': 'vcnId',
            'subnet_id': 'subnetId'
        }

        self._network_endpoint_type = None
        self._vcn_id = None
        self._subnet_id = None
        self._network_endpoint_type = 'PRIVATE'

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this PrivateEndpointDetails.
        The VCN OCID for the private endpoint.


        :return: The vcn_id of this PrivateEndpointDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this PrivateEndpointDetails.
        The VCN OCID for the private endpoint.


        :param vcn_id: The vcn_id of this PrivateEndpointDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this PrivateEndpointDetails.
        The subnet OCID for the private endpoint.


        :return: The subnet_id of this PrivateEndpointDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this PrivateEndpointDetails.
        The subnet OCID for the private endpoint.


        :param subnet_id: The subnet_id of this PrivateEndpointDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConditionOperator(object):
    """
    Conditions related to the parameter data type
    """

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "AND"
    NAME_AND = "AND"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "OR"
    NAME_OR = "OR"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "IN"
    NAME_IN = "IN"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "NOT_IN"
    NAME_NOT_IN = "NOT_IN"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "EQUALS"
    NAME_EQUALS = "EQUALS"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "NOT_EQUALS"
    NAME_NOT_EQUALS = "NOT_EQUALS"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "LESS_THAN"
    NAME_LESS_THAN = "LESS_THAN"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "GREATER_THAN"
    NAME_GREATER_THAN = "GREATER_THAN"

    #: A constant which can be used with the name property of a ConditionOperator.
    #: This constant has a value of "RANGE"
    NAME_RANGE = "RANGE"

    def __init__(self, **kwargs):
        """
        Initializes a new ConditionOperator object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ConditionOperator.
            Allowed values for this property are: "AND", "OR", "IN", "NOT_IN", "EQUALS", "NOT_EQUALS", "LESS_THAN", "GREATER_THAN", "RANGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this ConditionOperator.
        :type display_name: str

        """
        self.swagger_types = {
            'name': 'str',
            'display_name': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'display_name': 'displayName'
        }

        self._name = None
        self._display_name = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ConditionOperator.
        operator name

        Allowed values for this property are: "AND", "OR", "IN", "NOT_IN", "EQUALS", "NOT_EQUALS", "LESS_THAN", "GREATER_THAN", "RANGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this ConditionOperator.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConditionOperator.
        operator name


        :param name: The name of this ConditionOperator.
        :type: str
        """
        allowed_values = ["AND", "OR", "IN", "NOT_IN", "EQUALS", "NOT_EQUALS", "LESS_THAN", "GREATER_THAN", "RANGE"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ConditionOperator.
        display name of the operator


        :return: The display_name of this ConditionOperator.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ConditionOperator.
        display name of the operator


        :param display_name: The display_name of this ConditionOperator.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ServiceConnectorSummary(object):
    """
    A summary of properties for the specified service connector.
    """

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ServiceConnectorSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ServiceConnectorSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ServiceConnectorSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this ServiceConnectorSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this ServiceConnectorSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ServiceConnectorSummary.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this ServiceConnectorSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ServiceConnectorSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ServiceConnectorSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ServiceConnectorSummary.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ServiceConnectorSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ServiceConnectorSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this ServiceConnectorSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ServiceConnectorSummary.
        The `OCID`__ of the service connector.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ServiceConnectorSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServiceConnectorSummary.
        The `OCID`__ of the service connector.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ServiceConnectorSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ServiceConnectorSummary.
        A user-friendly name. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.


        :return: The display_name of this ServiceConnectorSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ServiceConnectorSummary.
        A user-friendly name. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this ServiceConnectorSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this ServiceConnectorSummary.
        The description of the resource. Avoid entering confidential information.


        :return: The description of this ServiceConnectorSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ServiceConnectorSummary.
        The description of the resource. Avoid entering confidential information.


        :param description: The description of this ServiceConnectorSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ServiceConnectorSummary.
        The `OCID`__ of the compartment containing the service connector.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ServiceConnectorSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ServiceConnectorSummary.
        The `OCID`__ of the compartment containing the service connector.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ServiceConnectorSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ServiceConnectorSummary.
        The date and time when the service connector was created.
        Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ServiceConnectorSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ServiceConnectorSummary.
        The date and time when the service connector was created.
        Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ServiceConnectorSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this ServiceConnectorSummary.
        The date and time when the service connector was updated.
        Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this ServiceConnectorSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ServiceConnectorSummary.
        The date and time when the service connector was updated.
        Format is defined by `RFC3339`__.
        Example: `2020-01-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this ServiceConnectorSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ServiceConnectorSummary.
        The current state of the service connector.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ServiceConnectorSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ServiceConnectorSummary.
        The current state of the service connector.


        :param lifecycle_state: The lifecycle_state of this ServiceConnectorSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ServiceConnectorSummary.
        A message describing the current state in more detail.
        For example, the message might provide actionable
        information for a resource in a `FAILED` state.


        :return: The lifecycle_details of this ServiceConnectorSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ServiceConnectorSummary.
        A message describing the current state in more detail.
        For example, the message might provide actionable
        information for a resource in a `FAILED` state.


        :param lifecycle_details: The lifecycle_details of this ServiceConnectorSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ServiceConnectorSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ServiceConnectorSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ServiceConnectorSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ServiceConnectorSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ServiceConnectorSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ServiceConnectorSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ServiceConnectorSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ServiceConnectorSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this ServiceConnectorSummary.
        The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this ServiceConnectorSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this ServiceConnectorSummary.
        The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this ServiceConnectorSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestResource(object):
    """
    WorkRequestResource model.
    """

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "COMPARTMENT_CHANGED"
    ACTION_RESULT_COMPARTMENT_CHANGED = "COMPARTMENT_CHANGED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "CREATED"
    ACTION_RESULT_CREATED = "CREATED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "DELETED"
    ACTION_RESULT_DELETED = "DELETED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "STARTED"
    ACTION_RESULT_STARTED = "STARTED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "STOPPED"
    ACTION_RESULT_STOPPED = "STOPPED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "SCALED"
    ACTION_RESULT_SCALED = "SCALED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "NETWORK_ENDPOINT_CHANGED"
    ACTION_RESULT_NETWORK_ENDPOINT_CHANGED = "NETWORK_ENDPOINT_CHANGED"

    #: A constant which can be used with the action_result property of a WorkRequestResource.
    #: This constant has a value of "NONE"
    ACTION_RESULT_NONE = "NONE"

    #: A constant which can be used with the resource_type property of a WorkRequestResource.
    #: This constant has a value of "ANALYTICS_INSTANCE"
    RESOURCE_TYPE_ANALYTICS_INSTANCE = "ANALYTICS_INSTANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestResource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action_result:
            The value to assign to the action_result property of this WorkRequestResource.
            Allowed values for this property are: "COMPARTMENT_CHANGED", "CREATED", "DELETED", "STARTED", "STOPPED", "SCALED", "NETWORK_ENDPOINT_CHANGED", "NONE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action_result: str

        :param resource_type:
            The value to assign to the resource_type property of this WorkRequestResource.
            Allowed values for this property are: "ANALYTICS_INSTANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_type: str

        :param identifier:
            The value to assign to the identifier property of this WorkRequestResource.
        :type identifier: str

        :param resource_uri:
            The value to assign to the resource_uri property of this WorkRequestResource.
        :type resource_uri: str

        :param metadata:
            The value to assign to the metadata property of this WorkRequestResource.
        :type metadata: dict(str, str)

        """
        self.swagger_types = {
            'action_result': 'str',
            'resource_type': 'str',
            'identifier': 'str',
            'resource_uri': 'str',
            'metadata': 'dict(str, str)'
        }

        self.attribute_map = {
            'action_result': 'actionResult',
            'resource_type': 'resourceType',
            'identifier': 'identifier',
            'resource_uri': 'resourceUri',
            'metadata': 'metadata'
        }

        self._action_result = None
        self._resource_type = None
        self._identifier = None
        self._resource_uri = None
        self._metadata = None

    @property
    def action_result(self):
        """
        **[Required]** Gets the action_result of this WorkRequestResource.
        The way in which this resource was affected by this work request.

        Allowed values for this property are: "COMPARTMENT_CHANGED", "CREATED", "DELETED", "STARTED", "STOPPED", "SCALED", "NETWORK_ENDPOINT_CHANGED", "NONE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action_result of this WorkRequestResource.
        :rtype: str
        """
        return self._action_result

    @action_result.setter
    def action_result(self, action_result):
        """
        Sets the action_result of this WorkRequestResource.
        The way in which this resource was affected by this work request.


        :param action_result: The action_result of this WorkRequestResource.
        :type: str
        """
        allowed_values = ["COMPARTMENT_CHANGED", "CREATED", "DELETED", "STARTED", "STOPPED", "SCALED", "NETWORK_ENDPOINT_CHANGED", "NONE"]
        if not value_allowed_none_or_none_sentinel(action_result, allowed_values):
            action_result = 'UNKNOWN_ENUM_VALUE'
        self._action_result = action_result

    @property
    def resource_type(self):
        """
        **[Required]** Gets the resource_type of this WorkRequestResource.
        The type of the resource the work request is affecting.

        Allowed values for this property are: "ANALYTICS_INSTANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_type of this WorkRequestResource.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this WorkRequestResource.
        The type of the resource the work request is affecting.


        :param resource_type: The resource_type of this WorkRequestResource.
        :type: str
        """
        allowed_values = ["ANALYTICS_INSTANCE"]
        if not value_allowed_none_or_none_sentinel(resource_type, allowed_values):
            resource_type = 'UNKNOWN_ENUM_VALUE'
        self._resource_type = resource_type

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this WorkRequestResource.
        The OCID of the resource the work request is affecting.


        :return: The identifier of this WorkRequestResource.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this WorkRequestResource.
        The OCID of the resource the work request is affecting.


        :param identifier: The identifier of this WorkRequestResource.
        :type: str
        """
        self._identifier = identifier

    @property
    def resource_uri(self):
        """
        **[Required]** Gets the resource_uri of this WorkRequestResource.
        The URI of the affected resource.


        :return: The resource_uri of this WorkRequestResource.
        :rtype: str
        """
        return self._resource_uri

    @resource_uri.setter
    def resource_uri(self, resource_uri):
        """
        Sets the resource_uri of this WorkRequestResource.
        The URI of the affected resource.


        :param resource_uri: The resource_uri of this WorkRequestResource.
        :type: str
        """
        self._resource_uri = resource_uri

    @property
    def metadata(self):
        """
        Gets the metadata of this WorkRequestResource.
        Additional metadata of the resource.


        :return: The metadata of this WorkRequestResource.
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this WorkRequestResource.
        Additional metadata of the resource.


        :param metadata: The metadata of this WorkRequestResource.
        :type: dict(str, str)
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsParserField(object):
    """
    LogAnalyticsParserField
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsParserField object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param field:
            The value to assign to the field property of this LogAnalyticsParserField.
        :type field: LogAnalyticsField

        :param parser_field_id:
            The value to assign to the parser_field_id property of this LogAnalyticsParserField.
        :type parser_field_id: int

        :param parser_field_expression:
            The value to assign to the parser_field_expression property of this LogAnalyticsParserField.
        :type parser_field_expression: str

        :param parser_field_name:
            The value to assign to the parser_field_name property of this LogAnalyticsParserField.
        :type parser_field_name: str

        :param storage_field_name:
            The value to assign to the storage_field_name property of this LogAnalyticsParserField.
        :type storage_field_name: str

        :param parser_field_integrator_name:
            The value to assign to the parser_field_integrator_name property of this LogAnalyticsParserField.
        :type parser_field_integrator_name: str

        :param parser_name:
            The value to assign to the parser_name property of this LogAnalyticsParserField.
        :type parser_name: str

        :param parser_field_sequence:
            The value to assign to the parser_field_sequence property of this LogAnalyticsParserField.
        :type parser_field_sequence: int

        :param parser:
            The value to assign to the parser property of this LogAnalyticsParserField.
        :type parser: LogAnalyticsParser

        :param structured_column_info:
            The value to assign to the structured_column_info property of this LogAnalyticsParserField.
        :type structured_column_info: str

        """
        self.swagger_types = {
            'field': 'LogAnalyticsField',
            'parser_field_id': 'int',
            'parser_field_expression': 'str',
            'parser_field_name': 'str',
            'storage_field_name': 'str',
            'parser_field_integrator_name': 'str',
            'parser_name': 'str',
            'parser_field_sequence': 'int',
            'parser': 'LogAnalyticsParser',
            'structured_column_info': 'str'
        }

        self.attribute_map = {
            'field': 'field',
            'parser_field_id': 'parserFieldId',
            'parser_field_expression': 'parserFieldExpression',
            'parser_field_name': 'parserFieldName',
            'storage_field_name': 'storageFieldName',
            'parser_field_integrator_name': 'parserFieldIntegratorName',
            'parser_name': 'parserName',
            'parser_field_sequence': 'parserFieldSequence',
            'parser': 'parser',
            'structured_column_info': 'structuredColumnInfo'
        }

        self._field = None
        self._parser_field_id = None
        self._parser_field_expression = None
        self._parser_field_name = None
        self._storage_field_name = None
        self._parser_field_integrator_name = None
        self._parser_name = None
        self._parser_field_sequence = None
        self._parser = None
        self._structured_column_info = None

    @property
    def field(self):
        """
        Gets the field of this LogAnalyticsParserField.

        :return: The field of this LogAnalyticsParserField.
        :rtype: LogAnalyticsField
        """
        return self._field

    @field.setter
    def field(self, field):
        """
        Sets the field of this LogAnalyticsParserField.

        :param field: The field of this LogAnalyticsParserField.
        :type: LogAnalyticsField
        """
        self._field = field

    @property
    def parser_field_id(self):
        """
        Gets the parser_field_id of this LogAnalyticsParserField.
        parser field map Id


        :return: The parser_field_id of this LogAnalyticsParserField.
        :rtype: int
        """
        return self._parser_field_id

    @parser_field_id.setter
    def parser_field_id(self, parser_field_id):
        """
        Sets the parser_field_id of this LogAnalyticsParserField.
        parser field map Id


        :param parser_field_id: The parser_field_id of this LogAnalyticsParserField.
        :type: int
        """
        self._parser_field_id = parser_field_id

    @property
    def parser_field_expression(self):
        """
        Gets the parser_field_expression of this LogAnalyticsParserField.
        field expression


        :return: The parser_field_expression of this LogAnalyticsParserField.
        :rtype: str
        """
        return self._parser_field_expression

    @parser_field_expression.setter
    def parser_field_expression(self, parser_field_expression):
        """
        Sets the parser_field_expression of this LogAnalyticsParserField.
        field expression


        :param parser_field_expression: The parser_field_expression of this LogAnalyticsParserField.
        :type: str
        """
        self._parser_field_expression = parser_field_expression

    @property
    def parser_field_name(self):
        """
        Gets the parser_field_name of this LogAnalyticsParserField.
        field internal name


        :return: The parser_field_name of this LogAnalyticsParserField.
        :rtype: str
        """
        return self._parser_field_name

    @parser_field_name.setter
    def parser_field_name(self, parser_field_name):
        """
        Sets the parser_field_name of this LogAnalyticsParserField.
        field internal name


        :param parser_field_name: The parser_field_name of this LogAnalyticsParserField.
        :type: str
        """
        self._parser_field_name = parser_field_name

    @property
    def storage_field_name(self):
        """
        Gets the storage_field_name of this LogAnalyticsParserField.
        internal name


        :return: The storage_field_name of this LogAnalyticsParserField.
        :rtype: str
        """
        return self._storage_field_name

    @storage_field_name.setter
    def storage_field_name(self, storage_field_name):
        """
        Sets the storage_field_name of this LogAnalyticsParserField.
        internal name


        :param storage_field_name: The storage_field_name of this LogAnalyticsParserField.
        :type: str
        """
        self._storage_field_name = storage_field_name

    @property
    def parser_field_integrator_name(self):
        """
        Gets the parser_field_integrator_name of this LogAnalyticsParserField.
        integrator name


        :return: The parser_field_integrator_name of this LogAnalyticsParserField.
        :rtype: str
        """
        return self._parser_field_integrator_name

    @parser_field_integrator_name.setter
    def parser_field_integrator_name(self, parser_field_integrator_name):
        """
        Sets the parser_field_integrator_name of this LogAnalyticsParserField.
        integrator name


        :param parser_field_integrator_name: The parser_field_integrator_name of this LogAnalyticsParserField.
        :type: str
        """
        self._parser_field_integrator_name = parser_field_integrator_name

    @property
    def parser_name(self):
        """
        Gets the parser_name of this LogAnalyticsParserField.
        parser internal name


        :return: The parser_name of this LogAnalyticsParserField.
        :rtype: str
        """
        return self._parser_name

    @parser_name.setter
    def parser_name(self, parser_name):
        """
        Sets the parser_name of this LogAnalyticsParserField.
        parser internal name


        :param parser_name: The parser_name of this LogAnalyticsParserField.
        :type: str
        """
        self._parser_name = parser_name

    @property
    def parser_field_sequence(self):
        """
        Gets the parser_field_sequence of this LogAnalyticsParserField.
        sequence


        :return: The parser_field_sequence of this LogAnalyticsParserField.
        :rtype: int
        """
        return self._parser_field_sequence

    @parser_field_sequence.setter
    def parser_field_sequence(self, parser_field_sequence):
        """
        Sets the parser_field_sequence of this LogAnalyticsParserField.
        sequence


        :param parser_field_sequence: The parser_field_sequence of this LogAnalyticsParserField.
        :type: int
        """
        self._parser_field_sequence = parser_field_sequence

    @property
    def parser(self):
        """
        Gets the parser of this LogAnalyticsParserField.

        :return: The parser of this LogAnalyticsParserField.
        :rtype: LogAnalyticsParser
        """
        return self._parser

    @parser.setter
    def parser(self, parser):
        """
        Sets the parser of this LogAnalyticsParserField.

        :param parser: The parser of this LogAnalyticsParserField.
        :type: LogAnalyticsParser
        """
        self._parser = parser

    @property
    def structured_column_info(self):
        """
        Gets the structured_column_info of this LogAnalyticsParserField.
        structured column information


        :return: The structured_column_info of this LogAnalyticsParserField.
        :rtype: str
        """
        return self._structured_column_info

    @structured_column_info.setter
    def structured_column_info(self, structured_column_info):
        """
        Sets the structured_column_info of this LogAnalyticsParserField.
        structured column information


        :param structured_column_info: The structured_column_info of this LogAnalyticsParserField.
        :type: str
        """
        self._structured_column_info = structured_column_info

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousContainerDatabase(object):
    """
    AutonomousContainerDatabase model.
    """

    #: A constant which can be used with the service_level_agreement_type property of a AutonomousContainerDatabase.
    #: This constant has a value of "STANDARD"
    SERVICE_LEVEL_AGREEMENT_TYPE_STANDARD = "STANDARD"

    #: A constant which can be used with the service_level_agreement_type property of a AutonomousContainerDatabase.
    #: This constant has a value of "MISSION_CRITICAL"
    SERVICE_LEVEL_AGREEMENT_TYPE_MISSION_CRITICAL = "MISSION_CRITICAL"

    #: A constant which can be used with the infrastructure_type property of a AutonomousContainerDatabase.
    #: This constant has a value of "CLOUD"
    INFRASTRUCTURE_TYPE_CLOUD = "CLOUD"

    #: A constant which can be used with the infrastructure_type property of a AutonomousContainerDatabase.
    #: This constant has a value of "CLOUD_AT_CUSTOMER"
    INFRASTRUCTURE_TYPE_CLOUD_AT_CUSTOMER = "CLOUD_AT_CUSTOMER"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "BACKUP_IN_PROGRESS"
    LIFECYCLE_STATE_BACKUP_IN_PROGRESS = "BACKUP_IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "RESTORING"
    LIFECYCLE_STATE_RESTORING = "RESTORING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "RESTORE_FAILED"
    LIFECYCLE_STATE_RESTORE_FAILED = "RESTORE_FAILED"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "RESTARTING"
    LIFECYCLE_STATE_RESTARTING = "RESTARTING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousContainerDatabase.
    #: This constant has a value of "MAINTENANCE_IN_PROGRESS"
    LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = "MAINTENANCE_IN_PROGRESS"

    #: A constant which can be used with the patch_model property of a AutonomousContainerDatabase.
    #: This constant has a value of "RELEASE_UPDATES"
    PATCH_MODEL_RELEASE_UPDATES = "RELEASE_UPDATES"

    #: A constant which can be used with the patch_model property of a AutonomousContainerDatabase.
    #: This constant has a value of "RELEASE_UPDATE_REVISIONS"
    PATCH_MODEL_RELEASE_UPDATE_REVISIONS = "RELEASE_UPDATE_REVISIONS"

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousContainerDatabase object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AutonomousContainerDatabase.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AutonomousContainerDatabase.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this AutonomousContainerDatabase.
        :type display_name: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this AutonomousContainerDatabase.
        :type db_unique_name: str

        :param service_level_agreement_type:
            The value to assign to the service_level_agreement_type property of this AutonomousContainerDatabase.
            Allowed values for this property are: "STANDARD", "MISSION_CRITICAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type service_level_agreement_type: str

        :param autonomous_exadata_infrastructure_id:
            The value to assign to the autonomous_exadata_infrastructure_id property of this AutonomousContainerDatabase.
        :type autonomous_exadata_infrastructure_id: str

        :param autonomous_vm_cluster_id:
            The value to assign to the autonomous_vm_cluster_id property of this AutonomousContainerDatabase.
        :type autonomous_vm_cluster_id: str

        :param infrastructure_type:
            The value to assign to the infrastructure_type property of this AutonomousContainerDatabase.
            Allowed values for this property are: "CLOUD", "CLOUD_AT_CUSTOMER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type infrastructure_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AutonomousContainerDatabase.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "BACKUP_IN_PROGRESS", "RESTORING", "RESTORE_FAILED", "RESTARTING", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this AutonomousContainerDatabase.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this AutonomousContainerDatabase.
        :type time_created: datetime

        :param patch_model:
            The value to assign to the patch_model property of this AutonomousContainerDatabase.
            Allowed values for this property are: "RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patch_model: str

        :param patch_id:
            The value to assign to the patch_id property of this AutonomousContainerDatabase.
        :type patch_id: str

        :param last_maintenance_run_id:
            The value to assign to the last_maintenance_run_id property of this AutonomousContainerDatabase.
        :type last_maintenance_run_id: str

        :param next_maintenance_run_id:
            The value to assign to the next_maintenance_run_id property of this AutonomousContainerDatabase.
        :type next_maintenance_run_id: str

        :param maintenance_window:
            The value to assign to the maintenance_window property of this AutonomousContainerDatabase.
        :type maintenance_window: MaintenanceWindow

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AutonomousContainerDatabase.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this AutonomousContainerDatabase.
        :type defined_tags: dict(str, dict(str, object))

        :param availability_domain:
            The value to assign to the availability_domain property of this AutonomousContainerDatabase.
        :type availability_domain: str

        :param db_version:
            The value to assign to the db_version property of this AutonomousContainerDatabase.
        :type db_version: str

        :param backup_config:
            The value to assign to the backup_config property of this AutonomousContainerDatabase.
        :type backup_config: AutonomousContainerDatabaseBackupConfig

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'db_unique_name': 'str',
            'service_level_agreement_type': 'str',
            'autonomous_exadata_infrastructure_id': 'str',
            'autonomous_vm_cluster_id': 'str',
            'infrastructure_type': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'patch_model': 'str',
            'patch_id': 'str',
            'last_maintenance_run_id': 'str',
            'next_maintenance_run_id': 'str',
            'maintenance_window': 'MaintenanceWindow',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'availability_domain': 'str',
            'db_version': 'str',
            'backup_config': 'AutonomousContainerDatabaseBackupConfig'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'db_unique_name': 'dbUniqueName',
            'service_level_agreement_type': 'serviceLevelAgreementType',
            'autonomous_exadata_infrastructure_id': 'autonomousExadataInfrastructureId',
            'autonomous_vm_cluster_id': 'autonomousVmClusterId',
            'infrastructure_type': 'infrastructureType',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'patch_model': 'patchModel',
            'patch_id': 'patchId',
            'last_maintenance_run_id': 'lastMaintenanceRunId',
            'next_maintenance_run_id': 'nextMaintenanceRunId',
            'maintenance_window': 'maintenanceWindow',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'availability_domain': 'availabilityDomain',
            'db_version': 'dbVersion',
            'backup_config': 'backupConfig'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._db_unique_name = None
        self._service_level_agreement_type = None
        self._autonomous_exadata_infrastructure_id = None
        self._autonomous_vm_cluster_id = None
        self._infrastructure_type = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._patch_model = None
        self._patch_id = None
        self._last_maintenance_run_id = None
        self._next_maintenance_run_id = None
        self._maintenance_window = None
        self._freeform_tags = None
        self._defined_tags = None
        self._availability_domain = None
        self._db_version = None
        self._backup_config = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutonomousContainerDatabase.
        The OCID of the Autonomous Container Database.


        :return: The id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutonomousContainerDatabase.
        The OCID of the Autonomous Container Database.


        :param id: The id of this AutonomousContainerDatabase.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AutonomousContainerDatabase.
        The OCID of the compartment.


        :return: The compartment_id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AutonomousContainerDatabase.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this AutonomousContainerDatabase.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AutonomousContainerDatabase.
        The user-provided name for the Autonomous Container Database.


        :return: The display_name of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AutonomousContainerDatabase.
        The user-provided name for the Autonomous Container Database.


        :param display_name: The display_name of this AutonomousContainerDatabase.
        :type: str
        """
        self._display_name = display_name

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this AutonomousContainerDatabase.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :return: The db_unique_name of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this AutonomousContainerDatabase.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :param db_unique_name: The db_unique_name of this AutonomousContainerDatabase.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def service_level_agreement_type(self):
        """
        **[Required]** Gets the service_level_agreement_type of this AutonomousContainerDatabase.
        The service level agreement type of the container database. The default is STANDARD.

        Allowed values for this property are: "STANDARD", "MISSION_CRITICAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The service_level_agreement_type of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._service_level_agreement_type

    @service_level_agreement_type.setter
    def service_level_agreement_type(self, service_level_agreement_type):
        """
        Sets the service_level_agreement_type of this AutonomousContainerDatabase.
        The service level agreement type of the container database. The default is STANDARD.


        :param service_level_agreement_type: The service_level_agreement_type of this AutonomousContainerDatabase.
        :type: str
        """
        allowed_values = ["STANDARD", "MISSION_CRITICAL"]
        if not value_allowed_none_or_none_sentinel(service_level_agreement_type, allowed_values):
            service_level_agreement_type = 'UNKNOWN_ENUM_VALUE'
        self._service_level_agreement_type = service_level_agreement_type

    @property
    def autonomous_exadata_infrastructure_id(self):
        """
        Gets the autonomous_exadata_infrastructure_id of this AutonomousContainerDatabase.
        The OCID of the Autonomous Exadata Infrastructure.


        :return: The autonomous_exadata_infrastructure_id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._autonomous_exadata_infrastructure_id

    @autonomous_exadata_infrastructure_id.setter
    def autonomous_exadata_infrastructure_id(self, autonomous_exadata_infrastructure_id):
        """
        Sets the autonomous_exadata_infrastructure_id of this AutonomousContainerDatabase.
        The OCID of the Autonomous Exadata Infrastructure.


        :param autonomous_exadata_infrastructure_id: The autonomous_exadata_infrastructure_id of this AutonomousContainerDatabase.
        :type: str
        """
        self._autonomous_exadata_infrastructure_id = autonomous_exadata_infrastructure_id

    @property
    def autonomous_vm_cluster_id(self):
        """
        Gets the autonomous_vm_cluster_id of this AutonomousContainerDatabase.
        The OCID of the Autonomous VM Cluster.


        :return: The autonomous_vm_cluster_id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._autonomous_vm_cluster_id

    @autonomous_vm_cluster_id.setter
    def autonomous_vm_cluster_id(self, autonomous_vm_cluster_id):
        """
        Sets the autonomous_vm_cluster_id of this AutonomousContainerDatabase.
        The OCID of the Autonomous VM Cluster.


        :param autonomous_vm_cluster_id: The autonomous_vm_cluster_id of this AutonomousContainerDatabase.
        :type: str
        """
        self._autonomous_vm_cluster_id = autonomous_vm_cluster_id

    @property
    def infrastructure_type(self):
        """
        Gets the infrastructure_type of this AutonomousContainerDatabase.
        The infrastructure type this resource belongs to.

        Allowed values for this property are: "CLOUD", "CLOUD_AT_CUSTOMER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The infrastructure_type of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._infrastructure_type

    @infrastructure_type.setter
    def infrastructure_type(self, infrastructure_type):
        """
        Sets the infrastructure_type of this AutonomousContainerDatabase.
        The infrastructure type this resource belongs to.


        :param infrastructure_type: The infrastructure_type of this AutonomousContainerDatabase.
        :type: str
        """
        allowed_values = ["CLOUD", "CLOUD_AT_CUSTOMER"]
        if not value_allowed_none_or_none_sentinel(infrastructure_type, allowed_values):
            infrastructure_type = 'UNKNOWN_ENUM_VALUE'
        self._infrastructure_type = infrastructure_type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AutonomousContainerDatabase.
        The current state of the Autonomous Container Database.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "BACKUP_IN_PROGRESS", "RESTORING", "RESTORE_FAILED", "RESTARTING", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AutonomousContainerDatabase.
        The current state of the Autonomous Container Database.


        :param lifecycle_state: The lifecycle_state of this AutonomousContainerDatabase.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "BACKUP_IN_PROGRESS", "RESTORING", "RESTORE_FAILED", "RESTARTING", "MAINTENANCE_IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this AutonomousContainerDatabase.
        Additional information about the current lifecycleState.


        :return: The lifecycle_details of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this AutonomousContainerDatabase.
        Additional information about the current lifecycleState.


        :param lifecycle_details: The lifecycle_details of this AutonomousContainerDatabase.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        Gets the time_created of this AutonomousContainerDatabase.
        The date and time the Autonomous Container Database was created.


        :return: The time_created of this AutonomousContainerDatabase.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AutonomousContainerDatabase.
        The date and time the Autonomous Container Database was created.


        :param time_created: The time_created of this AutonomousContainerDatabase.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def patch_model(self):
        """
        **[Required]** Gets the patch_model of this AutonomousContainerDatabase.
        Database patch model preference.

        Allowed values for this property are: "RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patch_model of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._patch_model

    @patch_model.setter
    def patch_model(self, patch_model):
        """
        Sets the patch_model of this AutonomousContainerDatabase.
        Database patch model preference.


        :param patch_model: The patch_model of this AutonomousContainerDatabase.
        :type: str
        """
        allowed_values = ["RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"]
        if not value_allowed_none_or_none_sentinel(patch_model, allowed_values):
            patch_model = 'UNKNOWN_ENUM_VALUE'
        self._patch_model = patch_model

    @property
    def patch_id(self):
        """
        Gets the patch_id of this AutonomousContainerDatabase.
        The `OCID`__ of the last patch applied on the system.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The patch_id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._patch_id

    @patch_id.setter
    def patch_id(self, patch_id):
        """
        Sets the patch_id of this AutonomousContainerDatabase.
        The `OCID`__ of the last patch applied on the system.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param patch_id: The patch_id of this AutonomousContainerDatabase.
        :type: str
        """
        self._patch_id = patch_id

    @property
    def last_maintenance_run_id(self):
        """
        Gets the last_maintenance_run_id of this AutonomousContainerDatabase.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_maintenance_run_id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._last_maintenance_run_id

    @last_maintenance_run_id.setter
    def last_maintenance_run_id(self, last_maintenance_run_id):
        """
        Sets the last_maintenance_run_id of this AutonomousContainerDatabase.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_maintenance_run_id: The last_maintenance_run_id of this AutonomousContainerDatabase.
        :type: str
        """
        self._last_maintenance_run_id = last_maintenance_run_id

    @property
    def next_maintenance_run_id(self):
        """
        Gets the next_maintenance_run_id of this AutonomousContainerDatabase.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The next_maintenance_run_id of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._next_maintenance_run_id

    @next_maintenance_run_id.setter
    def next_maintenance_run_id(self, next_maintenance_run_id):
        """
        Sets the next_maintenance_run_id of this AutonomousContainerDatabase.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param next_maintenance_run_id: The next_maintenance_run_id of this AutonomousContainerDatabase.
        :type: str
        """
        self._next_maintenance_run_id = next_maintenance_run_id

    @property
    def maintenance_window(self):
        """
        Gets the maintenance_window of this AutonomousContainerDatabase.

        :return: The maintenance_window of this AutonomousContainerDatabase.
        :rtype: MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """
        Sets the maintenance_window of this AutonomousContainerDatabase.

        :param maintenance_window: The maintenance_window of this AutonomousContainerDatabase.
        :type: MaintenanceWindow
        """
        self._maintenance_window = maintenance_window

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AutonomousContainerDatabase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this AutonomousContainerDatabase.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AutonomousContainerDatabase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this AutonomousContainerDatabase.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AutonomousContainerDatabase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this AutonomousContainerDatabase.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AutonomousContainerDatabase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this AutonomousContainerDatabase.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this AutonomousContainerDatabase.
        The availability domain of the Autonomous Container Database.


        :return: The availability_domain of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this AutonomousContainerDatabase.
        The availability domain of the Autonomous Container Database.


        :param availability_domain: The availability_domain of this AutonomousContainerDatabase.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def db_version(self):
        """
        Gets the db_version of this AutonomousContainerDatabase.
        Oracle Database version of the Autonomous Container Database


        :return: The db_version of this AutonomousContainerDatabase.
        :rtype: str
        """
        return self._db_version

    @db_version.setter
    def db_version(self, db_version):
        """
        Sets the db_version of this AutonomousContainerDatabase.
        Oracle Database version of the Autonomous Container Database


        :param db_version: The db_version of this AutonomousContainerDatabase.
        :type: str
        """
        self._db_version = db_version

    @property
    def backup_config(self):
        """
        Gets the backup_config of this AutonomousContainerDatabase.

        :return: The backup_config of this AutonomousContainerDatabase.
        :rtype: AutonomousContainerDatabaseBackupConfig
        """
        return self._backup_config

    @backup_config.setter
    def backup_config(self, backup_config):
        """
        Sets the backup_config of this AutonomousContainerDatabase.

        :param backup_config: The backup_config of this AutonomousContainerDatabase.
        :type: AutonomousContainerDatabaseBackupConfig
        """
        self._backup_config = backup_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Listing(object):
    """
    The model for an Oracle Cloud Infrastructure Marketplace listing.
    """

    #: A constant which can be used with the package_type property of a Listing.
    #: This constant has a value of "ORCHESTRATION"
    PACKAGE_TYPE_ORCHESTRATION = "ORCHESTRATION"

    #: A constant which can be used with the package_type property of a Listing.
    #: This constant has a value of "IMAGE"
    PACKAGE_TYPE_IMAGE = "IMAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new Listing object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Listing.
        :type id: str

        :param name:
            The value to assign to the name property of this Listing.
        :type name: str

        :param version:
            The value to assign to the version property of this Listing.
        :type version: str

        :param tagline:
            The value to assign to the tagline property of this Listing.
        :type tagline: str

        :param keywords:
            The value to assign to the keywords property of this Listing.
        :type keywords: str

        :param short_description:
            The value to assign to the short_description property of this Listing.
        :type short_description: str

        :param usage_information:
            The value to assign to the usage_information property of this Listing.
        :type usage_information: str

        :param long_description:
            The value to assign to the long_description property of this Listing.
        :type long_description: str

        :param license_model_description:
            The value to assign to the license_model_description property of this Listing.
        :type license_model_description: str

        :param system_requirements:
            The value to assign to the system_requirements property of this Listing.
        :type system_requirements: str

        :param time_released:
            The value to assign to the time_released property of this Listing.
        :type time_released: datetime

        :param release_notes:
            The value to assign to the release_notes property of this Listing.
        :type release_notes: str

        :param categories:
            The value to assign to the categories property of this Listing.
        :type categories: list[str]

        :param publisher:
            The value to assign to the publisher property of this Listing.
        :type publisher: Publisher

        :param languages:
            The value to assign to the languages property of this Listing.
        :type languages: list[Item]

        :param screenshots:
            The value to assign to the screenshots property of this Listing.
        :type screenshots: list[Screenshot]

        :param videos:
            The value to assign to the videos property of this Listing.
        :type videos: list[NamedLink]

        :param support_contacts:
            The value to assign to the support_contacts property of this Listing.
        :type support_contacts: list[SupportContact]

        :param support_links:
            The value to assign to the support_links property of this Listing.
        :type support_links: list[NamedLink]

        :param documentation_links:
            The value to assign to the documentation_links property of this Listing.
        :type documentation_links: list[DocumentationLink]

        :param icon:
            The value to assign to the icon property of this Listing.
        :type icon: UploadData

        :param banner:
            The value to assign to the banner property of this Listing.
        :type banner: UploadData

        :param regions:
            The value to assign to the regions property of this Listing.
        :type regions: list[Region]

        :param package_type:
            The value to assign to the package_type property of this Listing.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        :param default_package_version:
            The value to assign to the default_package_version property of this Listing.
        :type default_package_version: str

        :param links:
            The value to assign to the links property of this Listing.
        :type links: list[Link]

        :param is_featured:
            The value to assign to the is_featured property of this Listing.
        :type is_featured: bool

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'str',
            'tagline': 'str',
            'keywords': 'str',
            'short_description': 'str',
            'usage_information': 'str',
            'long_description': 'str',
            'license_model_description': 'str',
            'system_requirements': 'str',
            'time_released': 'datetime',
            'release_notes': 'str',
            'categories': 'list[str]',
            'publisher': 'Publisher',
            'languages': 'list[Item]',
            'screenshots': 'list[Screenshot]',
            'videos': 'list[NamedLink]',
            'support_contacts': 'list[SupportContact]',
            'support_links': 'list[NamedLink]',
            'documentation_links': 'list[DocumentationLink]',
            'icon': 'UploadData',
            'banner': 'UploadData',
            'regions': 'list[Region]',
            'package_type': 'str',
            'default_package_version': 'str',
            'links': 'list[Link]',
            'is_featured': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'tagline': 'tagline',
            'keywords': 'keywords',
            'short_description': 'shortDescription',
            'usage_information': 'usageInformation',
            'long_description': 'longDescription',
            'license_model_description': 'licenseModelDescription',
            'system_requirements': 'systemRequirements',
            'time_released': 'timeReleased',
            'release_notes': 'releaseNotes',
            'categories': 'categories',
            'publisher': 'publisher',
            'languages': 'languages',
            'screenshots': 'screenshots',
            'videos': 'videos',
            'support_contacts': 'supportContacts',
            'support_links': 'supportLinks',
            'documentation_links': 'documentationLinks',
            'icon': 'icon',
            'banner': 'banner',
            'regions': 'regions',
            'package_type': 'packageType',
            'default_package_version': 'defaultPackageVersion',
            'links': 'links',
            'is_featured': 'isFeatured'
        }

        self._id = None
        self._name = None
        self._version = None
        self._tagline = None
        self._keywords = None
        self._short_description = None
        self._usage_information = None
        self._long_description = None
        self._license_model_description = None
        self._system_requirements = None
        self._time_released = None
        self._release_notes = None
        self._categories = None
        self._publisher = None
        self._languages = None
        self._screenshots = None
        self._videos = None
        self._support_contacts = None
        self._support_links = None
        self._documentation_links = None
        self._icon = None
        self._banner = None
        self._regions = None
        self._package_type = None
        self._default_package_version = None
        self._links = None
        self._is_featured = None

    @property
    def id(self):
        """
        Gets the id of this Listing.
        The unique identifier for the listing in Marketplace.


        :return: The id of this Listing.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Listing.
        The unique identifier for the listing in Marketplace.


        :param id: The id of this Listing.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Listing.
        The name of the listing.


        :return: The name of this Listing.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Listing.
        The name of the listing.


        :param name: The name of this Listing.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this Listing.
        The version of the listing.


        :return: The version of this Listing.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Listing.
        The version of the listing.


        :param version: The version of this Listing.
        :type: str
        """
        self._version = version

    @property
    def tagline(self):
        """
        Gets the tagline of this Listing.
        The tagline of the listing.


        :return: The tagline of this Listing.
        :rtype: str
        """
        return self._tagline

    @tagline.setter
    def tagline(self, tagline):
        """
        Sets the tagline of this Listing.
        The tagline of the listing.


        :param tagline: The tagline of this Listing.
        :type: str
        """
        self._tagline = tagline

    @property
    def keywords(self):
        """
        Gets the keywords of this Listing.
        Keywords associated with the listing.


        :return: The keywords of this Listing.
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """
        Sets the keywords of this Listing.
        Keywords associated with the listing.


        :param keywords: The keywords of this Listing.
        :type: str
        """
        self._keywords = keywords

    @property
    def short_description(self):
        """
        Gets the short_description of this Listing.
        A short description of the listing.


        :return: The short_description of this Listing.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this Listing.
        A short description of the listing.


        :param short_description: The short_description of this Listing.
        :type: str
        """
        self._short_description = short_description

    @property
    def usage_information(self):
        """
        Gets the usage_information of this Listing.
        Usage information for the listing.


        :return: The usage_information of this Listing.
        :rtype: str
        """
        return self._usage_information

    @usage_information.setter
    def usage_information(self, usage_information):
        """
        Sets the usage_information of this Listing.
        Usage information for the listing.


        :param usage_information: The usage_information of this Listing.
        :type: str
        """
        self._usage_information = usage_information

    @property
    def long_description(self):
        """
        Gets the long_description of this Listing.
        A long description of the listing.


        :return: The long_description of this Listing.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this Listing.
        A long description of the listing.


        :param long_description: The long_description of this Listing.
        :type: str
        """
        self._long_description = long_description

    @property
    def license_model_description(self):
        """
        Gets the license_model_description of this Listing.
        A description of the publisher's licensing model for the listing.


        :return: The license_model_description of this Listing.
        :rtype: str
        """
        return self._license_model_description

    @license_model_description.setter
    def license_model_description(self, license_model_description):
        """
        Sets the license_model_description of this Listing.
        A description of the publisher's licensing model for the listing.


        :param license_model_description: The license_model_description of this Listing.
        :type: str
        """
        self._license_model_description = license_model_description

    @property
    def system_requirements(self):
        """
        Gets the system_requirements of this Listing.
        System requirements for the listing.


        :return: The system_requirements of this Listing.
        :rtype: str
        """
        return self._system_requirements

    @system_requirements.setter
    def system_requirements(self, system_requirements):
        """
        Sets the system_requirements of this Listing.
        System requirements for the listing.


        :param system_requirements: The system_requirements of this Listing.
        :type: str
        """
        self._system_requirements = system_requirements

    @property
    def time_released(self):
        """
        Gets the time_released of this Listing.
        The release date of the listing.


        :return: The time_released of this Listing.
        :rtype: datetime
        """
        return self._time_released

    @time_released.setter
    def time_released(self, time_released):
        """
        Sets the time_released of this Listing.
        The release date of the listing.


        :param time_released: The time_released of this Listing.
        :type: datetime
        """
        self._time_released = time_released

    @property
    def release_notes(self):
        """
        Gets the release_notes of this Listing.
        Release notes for the listing.


        :return: The release_notes of this Listing.
        :rtype: str
        """
        return self._release_notes

    @release_notes.setter
    def release_notes(self, release_notes):
        """
        Sets the release_notes of this Listing.
        Release notes for the listing.


        :param release_notes: The release_notes of this Listing.
        :type: str
        """
        self._release_notes = release_notes

    @property
    def categories(self):
        """
        Gets the categories of this Listing.
        Categories that the listing belongs to.


        :return: The categories of this Listing.
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this Listing.
        Categories that the listing belongs to.


        :param categories: The categories of this Listing.
        :type: list[str]
        """
        self._categories = categories

    @property
    def publisher(self):
        """
        Gets the publisher of this Listing.

        :return: The publisher of this Listing.
        :rtype: Publisher
        """
        return self._publisher

    @publisher.setter
    def publisher(self, publisher):
        """
        Sets the publisher of this Listing.

        :param publisher: The publisher of this Listing.
        :type: Publisher
        """
        self._publisher = publisher

    @property
    def languages(self):
        """
        Gets the languages of this Listing.
        Languages supported by the listing.


        :return: The languages of this Listing.
        :rtype: list[Item]
        """
        return self._languages

    @languages.setter
    def languages(self, languages):
        """
        Sets the languages of this Listing.
        Languages supported by the listing.


        :param languages: The languages of this Listing.
        :type: list[Item]
        """
        self._languages = languages

    @property
    def screenshots(self):
        """
        Gets the screenshots of this Listing.
        Screenshots of the listing.


        :return: The screenshots of this Listing.
        :rtype: list[Screenshot]
        """
        return self._screenshots

    @screenshots.setter
    def screenshots(self, screenshots):
        """
        Sets the screenshots of this Listing.
        Screenshots of the listing.


        :param screenshots: The screenshots of this Listing.
        :type: list[Screenshot]
        """
        self._screenshots = screenshots

    @property
    def videos(self):
        """
        Gets the videos of this Listing.
        Videos of the listing.


        :return: The videos of this Listing.
        :rtype: list[NamedLink]
        """
        return self._videos

    @videos.setter
    def videos(self, videos):
        """
        Sets the videos of this Listing.
        Videos of the listing.


        :param videos: The videos of this Listing.
        :type: list[NamedLink]
        """
        self._videos = videos

    @property
    def support_contacts(self):
        """
        Gets the support_contacts of this Listing.
        Contact information to use to get support from the publisher for the listing.


        :return: The support_contacts of this Listing.
        :rtype: list[SupportContact]
        """
        return self._support_contacts

    @support_contacts.setter
    def support_contacts(self, support_contacts):
        """
        Sets the support_contacts of this Listing.
        Contact information to use to get support from the publisher for the listing.


        :param support_contacts: The support_contacts of this Listing.
        :type: list[SupportContact]
        """
        self._support_contacts = support_contacts

    @property
    def support_links(self):
        """
        Gets the support_links of this Listing.
        Links to support resources for the listing.


        :return: The support_links of this Listing.
        :rtype: list[NamedLink]
        """
        return self._support_links

    @support_links.setter
    def support_links(self, support_links):
        """
        Sets the support_links of this Listing.
        Links to support resources for the listing.


        :param support_links: The support_links of this Listing.
        :type: list[NamedLink]
        """
        self._support_links = support_links

    @property
    def documentation_links(self):
        """
        Gets the documentation_links of this Listing.
        Links to additional documentation provided by the publisher specifically for the listing.


        :return: The documentation_links of this Listing.
        :rtype: list[DocumentationLink]
        """
        return self._documentation_links

    @documentation_links.setter
    def documentation_links(self, documentation_links):
        """
        Sets the documentation_links of this Listing.
        Links to additional documentation provided by the publisher specifically for the listing.


        :param documentation_links: The documentation_links of this Listing.
        :type: list[DocumentationLink]
        """
        self._documentation_links = documentation_links

    @property
    def icon(self):
        """
        Gets the icon of this Listing.

        :return: The icon of this Listing.
        :rtype: UploadData
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this Listing.

        :param icon: The icon of this Listing.
        :type: UploadData
        """
        self._icon = icon

    @property
    def banner(self):
        """
        Gets the banner of this Listing.

        :return: The banner of this Listing.
        :rtype: UploadData
        """
        return self._banner

    @banner.setter
    def banner(self, banner):
        """
        Sets the banner of this Listing.

        :param banner: The banner of this Listing.
        :type: UploadData
        """
        self._banner = banner

    @property
    def regions(self):
        """
        Gets the regions of this Listing.
        The regions where the listing is eligible to be deployed.


        :return: The regions of this Listing.
        :rtype: list[Region]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """
        Sets the regions of this Listing.
        The regions where the listing is eligible to be deployed.


        :param regions: The regions of this Listing.
        :type: list[Region]
        """
        self._regions = regions

    @property
    def package_type(self):
        """
        Gets the package_type of this Listing.
        The listing's package type.

        Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this Listing.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this Listing.
        The listing's package type.


        :param package_type: The package_type of this Listing.
        :type: str
        """
        allowed_values = ["ORCHESTRATION", "IMAGE"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    @property
    def default_package_version(self):
        """
        Gets the default_package_version of this Listing.
        The default package version.


        :return: The default_package_version of this Listing.
        :rtype: str
        """
        return self._default_package_version

    @default_package_version.setter
    def default_package_version(self, default_package_version):
        """
        Sets the default_package_version of this Listing.
        The default package version.


        :param default_package_version: The default_package_version of this Listing.
        :type: str
        """
        self._default_package_version = default_package_version

    @property
    def links(self):
        """
        Gets the links of this Listing.
        Links to reference material.


        :return: The links of this Listing.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this Listing.
        Links to reference material.


        :param links: The links of this Listing.
        :type: list[Link]
        """
        self._links = links

    @property
    def is_featured(self):
        """
        Gets the is_featured of this Listing.
        Indicates whether the listing is included in Featured Listings.


        :return: The is_featured of this Listing.
        :rtype: bool
        """
        return self._is_featured

    @is_featured.setter
    def is_featured(self, is_featured):
        """
        Sets the is_featured of this Listing.
        Indicates whether the listing is included in Featured Listings.


        :param is_featured: The is_featured of this Listing.
        :type: bool
        """
        self._is_featured = is_featured

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Duration(object):
    """
    The amount of time that objects in the bucket should be preserved for and which is calculated in relation to
    each object's Last-Modified timestamp. If duration is not present, then there is no time limit and the objects
    in the bucket will be preserved indefinitely.
    """

    #: A constant which can be used with the time_unit property of a Duration.
    #: This constant has a value of "YEARS"
    TIME_UNIT_YEARS = "YEARS"

    #: A constant which can be used with the time_unit property of a Duration.
    #: This constant has a value of "DAYS"
    TIME_UNIT_DAYS = "DAYS"

    def __init__(self, **kwargs):
        """
        Initializes a new Duration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_amount:
            The value to assign to the time_amount property of this Duration.
        :type time_amount: int

        :param time_unit:
            The value to assign to the time_unit property of this Duration.
            Allowed values for this property are: "YEARS", "DAYS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type time_unit: str

        """
        self.swagger_types = {
            'time_amount': 'int',
            'time_unit': 'str'
        }

        self.attribute_map = {
            'time_amount': 'timeAmount',
            'time_unit': 'timeUnit'
        }

        self._time_amount = None
        self._time_unit = None

    @property
    def time_amount(self):
        """
        **[Required]** Gets the time_amount of this Duration.
        The timeAmount is interpreted in units defined by the timeUnit parameter, and is calculated in relation
        to each object's Last-Modified timestamp.


        :return: The time_amount of this Duration.
        :rtype: int
        """
        return self._time_amount

    @time_amount.setter
    def time_amount(self, time_amount):
        """
        Sets the time_amount of this Duration.
        The timeAmount is interpreted in units defined by the timeUnit parameter, and is calculated in relation
        to each object's Last-Modified timestamp.


        :param time_amount: The time_amount of this Duration.
        :type: int
        """
        self._time_amount = time_amount

    @property
    def time_unit(self):
        """
        **[Required]** Gets the time_unit of this Duration.
        The unit that should be used to interpret timeAmount.

        Allowed values for this property are: "YEARS", "DAYS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The time_unit of this Duration.
        :rtype: str
        """
        return self._time_unit

    @time_unit.setter
    def time_unit(self, time_unit):
        """
        Sets the time_unit of this Duration.
        The unit that should be used to interpret timeAmount.


        :param time_unit: The time_unit of this Duration.
        :type: str
        """
        allowed_values = ["YEARS", "DAYS"]
        if not value_allowed_none_or_none_sentinel(time_unit, allowed_values):
            time_unit = 'UNKNOWN_ENUM_VALUE'
        self._time_unit = time_unit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateSubscriptionDetails(object):
    """
    The configuration details for creating the subscription.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateSubscriptionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param topic_id:
            The value to assign to the topic_id property of this CreateSubscriptionDetails.
        :type topic_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateSubscriptionDetails.
        :type compartment_id: str

        :param protocol:
            The value to assign to the protocol property of this CreateSubscriptionDetails.
        :type protocol: str

        :param endpoint:
            The value to assign to the endpoint property of this CreateSubscriptionDetails.
        :type endpoint: str

        :param metadata:
            The value to assign to the metadata property of this CreateSubscriptionDetails.
        :type metadata: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateSubscriptionDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateSubscriptionDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'topic_id': 'str',
            'compartment_id': 'str',
            'protocol': 'str',
            'endpoint': 'str',
            'metadata': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'topic_id': 'topicId',
            'compartment_id': 'compartmentId',
            'protocol': 'protocol',
            'endpoint': 'endpoint',
            'metadata': 'metadata',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._topic_id = None
        self._compartment_id = None
        self._protocol = None
        self._endpoint = None
        self._metadata = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def topic_id(self):
        """
        **[Required]** Gets the topic_id of this CreateSubscriptionDetails.
        The `OCID`__ of the topic for the subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The topic_id of this CreateSubscriptionDetails.
        :rtype: str
        """
        return self._topic_id

    @topic_id.setter
    def topic_id(self, topic_id):
        """
        Sets the topic_id of this CreateSubscriptionDetails.
        The `OCID`__ of the topic for the subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param topic_id: The topic_id of this CreateSubscriptionDetails.
        :type: str
        """
        self._topic_id = topic_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateSubscriptionDetails.
        The `OCID`__ of the compartment for the subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateSubscriptionDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateSubscriptionDetails.
        The `OCID`__ of the compartment for the subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateSubscriptionDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this CreateSubscriptionDetails.
        The protocol used for the subscription.

        Allowed values:
          * `CUSTOM_HTTPS`
          * `EMAIL`
          * `HTTPS` (deprecated; for PagerDuty endpoints, use `PAGERDUTY`)
          * `PAGERDUTY`
          * `SLACK`
          * `ORACLE_FUNCTIONS`

        For information about subscription protocols, see
        `To create a subscription`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub


        :return: The protocol of this CreateSubscriptionDetails.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this CreateSubscriptionDetails.
        The protocol used for the subscription.

        Allowed values:
          * `CUSTOM_HTTPS`
          * `EMAIL`
          * `HTTPS` (deprecated; for PagerDuty endpoints, use `PAGERDUTY`)
          * `PAGERDUTY`
          * `SLACK`
          * `ORACLE_FUNCTIONS`

        For information about subscription protocols, see
        `To create a subscription`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub


        :param protocol: The protocol of this CreateSubscriptionDetails.
        :type: str
        """
        self._protocol = protocol

    @property
    def endpoint(self):
        """
        **[Required]** Gets the endpoint of this CreateSubscriptionDetails.
        A locator that corresponds to the subscription protocol.
        For example, an email address for a subscription that uses the `EMAIL` protocol, or a URL for a subscription that uses an HTTP-based protocol.
        HTTP-based protocols use URL endpoints that begin with \"http:\" or \"https:\".
        A URL cannot exceed 512 characters.
        Avoid entering confidential information.

        For protocol-specific endpoint formats and steps to get or create endpoints, see
        `To create a subscription`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub


        :return: The endpoint of this CreateSubscriptionDetails.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this CreateSubscriptionDetails.
        A locator that corresponds to the subscription protocol.
        For example, an email address for a subscription that uses the `EMAIL` protocol, or a URL for a subscription that uses an HTTP-based protocol.
        HTTP-based protocols use URL endpoints that begin with \"http:\" or \"https:\".
        A URL cannot exceed 512 characters.
        Avoid entering confidential information.

        For protocol-specific endpoint formats and steps to get or create endpoints, see
        `To create a subscription`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub


        :param endpoint: The endpoint of this CreateSubscriptionDetails.
        :type: str
        """
        self._endpoint = endpoint

    @property
    def metadata(self):
        """
        Gets the metadata of this CreateSubscriptionDetails.
        Metadata for the subscription.


        :return: The metadata of this CreateSubscriptionDetails.
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this CreateSubscriptionDetails.
        Metadata for the subscription.


        :param metadata: The metadata of this CreateSubscriptionDetails.
        :type: str
        """
        self._metadata = metadata

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateSubscriptionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateSubscriptionDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateSubscriptionDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateSubscriptionDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateSubscriptionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateSubscriptionDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateSubscriptionDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateSubscriptionDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RunLogSummary(object):
    """
    A summary of a log associated with a particular run.
    """

    #: A constant which can be used with the source property of a RunLogSummary.
    #: This constant has a value of "APPLICATION"
    SOURCE_APPLICATION = "APPLICATION"

    #: A constant which can be used with the source property of a RunLogSummary.
    #: This constant has a value of "DRIVER"
    SOURCE_DRIVER = "DRIVER"

    #: A constant which can be used with the source property of a RunLogSummary.
    #: This constant has a value of "EXECUTOR"
    SOURCE_EXECUTOR = "EXECUTOR"

    #: A constant which can be used with the type property of a RunLogSummary.
    #: This constant has a value of "STDERR"
    TYPE_STDERR = "STDERR"

    #: A constant which can be used with the type property of a RunLogSummary.
    #: This constant has a value of "STDOUT"
    TYPE_STDOUT = "STDOUT"

    def __init__(self, **kwargs):
        """
        Initializes a new RunLogSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this RunLogSummary.
        :type name: str

        :param run_id:
            The value to assign to the run_id property of this RunLogSummary.
        :type run_id: str

        :param size_in_bytes:
            The value to assign to the size_in_bytes property of this RunLogSummary.
        :type size_in_bytes: int

        :param source:
            The value to assign to the source property of this RunLogSummary.
            Allowed values for this property are: "APPLICATION", "DRIVER", "EXECUTOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source: str

        :param time_created:
            The value to assign to the time_created property of this RunLogSummary.
        :type time_created: datetime

        :param type:
            The value to assign to the type property of this RunLogSummary.
            Allowed values for this property are: "STDERR", "STDOUT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        """
        self.swagger_types = {
            'name': 'str',
            'run_id': 'str',
            'size_in_bytes': 'int',
            'source': 'str',
            'time_created': 'datetime',
            'type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'run_id': 'runId',
            'size_in_bytes': 'sizeInBytes',
            'source': 'source',
            'time_created': 'timeCreated',
            'type': 'type'
        }

        self._name = None
        self._run_id = None
        self._size_in_bytes = None
        self._source = None
        self._time_created = None
        self._type = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this RunLogSummary.
        The name of the log.
        Example: spark_driver_stderr_20190917T114000Z.log.gz


        :return: The name of this RunLogSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this RunLogSummary.
        The name of the log.
        Example: spark_driver_stderr_20190917T114000Z.log.gz


        :param name: The name of this RunLogSummary.
        :type: str
        """
        self._name = name

    @property
    def run_id(self):
        """
        **[Required]** Gets the run_id of this RunLogSummary.
        The runId associated with the log.


        :return: The run_id of this RunLogSummary.
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """
        Sets the run_id of this RunLogSummary.
        The runId associated with the log.


        :param run_id: The run_id of this RunLogSummary.
        :type: str
        """
        self._run_id = run_id

    @property
    def size_in_bytes(self):
        """
        Gets the size_in_bytes of this RunLogSummary.
        The size of the object in bytes.


        :return: The size_in_bytes of this RunLogSummary.
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """
        Sets the size_in_bytes of this RunLogSummary.
        The size of the object in bytes.


        :param size_in_bytes: The size_in_bytes of this RunLogSummary.
        :type: int
        """
        self._size_in_bytes = size_in_bytes

    @property
    def source(self):
        """
        **[Required]** Gets the source of this RunLogSummary.
        The source of the log such as driver and executor.

        Allowed values for this property are: "APPLICATION", "DRIVER", "EXECUTOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source of this RunLogSummary.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this RunLogSummary.
        The source of the log such as driver and executor.


        :param source: The source of this RunLogSummary.
        :type: str
        """
        allowed_values = ["APPLICATION", "DRIVER", "EXECUTOR"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            source = 'UNKNOWN_ENUM_VALUE'
        self._source = source

    @property
    def time_created(self):
        """
        Gets the time_created of this RunLogSummary.
        The date and time the object was created, as described in `RFC 2616`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc2616


        :return: The time_created of this RunLogSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RunLogSummary.
        The date and time the object was created, as described in `RFC 2616`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc2616


        :param time_created: The time_created of this RunLogSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def type(self):
        """
        **[Required]** Gets the type of this RunLogSummary.
        The type of log such as stdout and stderr.

        Allowed values for this property are: "STDERR", "STDOUT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this RunLogSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this RunLogSummary.
        The type of log such as stdout and stderr.


        :param type: The type of this RunLogSummary.
        :type: str
        """
        allowed_values = ["STDERR", "STDOUT"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsSourceFunction(object):
    """
    LogAnalyticsSourceFunction
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsSourceFunction object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param arguments:
            The value to assign to the arguments property of this LogAnalyticsSourceFunction.
        :type arguments: list[LogAnalyticsMetaFunctionArgument]

        :param is_enabled:
            The value to assign to the is_enabled property of this LogAnalyticsSourceFunction.
        :type is_enabled: bool

        :param function:
            The value to assign to the function property of this LogAnalyticsSourceFunction.
        :type function: LogAnalyticsMetaFunction

        :param function_id:
            The value to assign to the function_id property of this LogAnalyticsSourceFunction.
        :type function_id: int

        :param order:
            The value to assign to the order property of this LogAnalyticsSourceFunction.
        :type order: int

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsSourceFunction.
        :type is_system: bool

        :param lookup_column:
            The value to assign to the lookup_column property of this LogAnalyticsSourceFunction.
        :type lookup_column: str

        :param lookup_column_position:
            The value to assign to the lookup_column_position property of this LogAnalyticsSourceFunction.
        :type lookup_column_position: int

        :param lookup_display_name:
            The value to assign to the lookup_display_name property of this LogAnalyticsSourceFunction.
        :type lookup_display_name: str

        :param lookup_mode:
            The value to assign to the lookup_mode property of this LogAnalyticsSourceFunction.
        :type lookup_mode: int

        :param lookup_table:
            The value to assign to the lookup_table property of this LogAnalyticsSourceFunction.
        :type lookup_table: str

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsSourceFunction.
        :type source_id: int

        """
        self.swagger_types = {
            'arguments': 'list[LogAnalyticsMetaFunctionArgument]',
            'is_enabled': 'bool',
            'function': 'LogAnalyticsMetaFunction',
            'function_id': 'int',
            'order': 'int',
            'is_system': 'bool',
            'lookup_column': 'str',
            'lookup_column_position': 'int',
            'lookup_display_name': 'str',
            'lookup_mode': 'int',
            'lookup_table': 'str',
            'source_id': 'int'
        }

        self.attribute_map = {
            'arguments': 'arguments',
            'is_enabled': 'isEnabled',
            'function': 'function',
            'function_id': 'functionId',
            'order': 'order',
            'is_system': 'isSystem',
            'lookup_column': 'lookupColumn',
            'lookup_column_position': 'lookupColumnPosition',
            'lookup_display_name': 'lookupDisplayName',
            'lookup_mode': 'lookupMode',
            'lookup_table': 'lookupTable',
            'source_id': 'sourceId'
        }

        self._arguments = None
        self._is_enabled = None
        self._function = None
        self._function_id = None
        self._order = None
        self._is_system = None
        self._lookup_column = None
        self._lookup_column_position = None
        self._lookup_display_name = None
        self._lookup_mode = None
        self._lookup_table = None
        self._source_id = None

    @property
    def arguments(self):
        """
        Gets the arguments of this LogAnalyticsSourceFunction.
        argument


        :return: The arguments of this LogAnalyticsSourceFunction.
        :rtype: list[LogAnalyticsMetaFunctionArgument]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """
        Sets the arguments of this LogAnalyticsSourceFunction.
        argument


        :param arguments: The arguments of this LogAnalyticsSourceFunction.
        :type: list[LogAnalyticsMetaFunctionArgument]
        """
        self._arguments = arguments

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this LogAnalyticsSourceFunction.
        enabled flag


        :return: The is_enabled of this LogAnalyticsSourceFunction.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this LogAnalyticsSourceFunction.
        enabled flag


        :param is_enabled: The is_enabled of this LogAnalyticsSourceFunction.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def function(self):
        """
        Gets the function of this LogAnalyticsSourceFunction.

        :return: The function of this LogAnalyticsSourceFunction.
        :rtype: LogAnalyticsMetaFunction
        """
        return self._function

    @function.setter
    def function(self, function):
        """
        Sets the function of this LogAnalyticsSourceFunction.

        :param function: The function of this LogAnalyticsSourceFunction.
        :type: LogAnalyticsMetaFunction
        """
        self._function = function

    @property
    def function_id(self):
        """
        Gets the function_id of this LogAnalyticsSourceFunction.
        source function Id


        :return: The function_id of this LogAnalyticsSourceFunction.
        :rtype: int
        """
        return self._function_id

    @function_id.setter
    def function_id(self, function_id):
        """
        Sets the function_id of this LogAnalyticsSourceFunction.
        source function Id


        :param function_id: The function_id of this LogAnalyticsSourceFunction.
        :type: int
        """
        self._function_id = function_id

    @property
    def order(self):
        """
        Gets the order of this LogAnalyticsSourceFunction.
        source function order


        :return: The order of this LogAnalyticsSourceFunction.
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this LogAnalyticsSourceFunction.
        source function order


        :param order: The order of this LogAnalyticsSourceFunction.
        :type: int
        """
        self._order = order

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsSourceFunction.
        is system flag


        :return: The is_system of this LogAnalyticsSourceFunction.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsSourceFunction.
        is system flag


        :param is_system: The is_system of this LogAnalyticsSourceFunction.
        :type: bool
        """
        self._is_system = is_system

    @property
    def lookup_column(self):
        """
        Gets the lookup_column of this LogAnalyticsSourceFunction.
        column


        :return: The lookup_column of this LogAnalyticsSourceFunction.
        :rtype: str
        """
        return self._lookup_column

    @lookup_column.setter
    def lookup_column(self, lookup_column):
        """
        Sets the lookup_column of this LogAnalyticsSourceFunction.
        column


        :param lookup_column: The lookup_column of this LogAnalyticsSourceFunction.
        :type: str
        """
        self._lookup_column = lookup_column

    @property
    def lookup_column_position(self):
        """
        Gets the lookup_column_position of this LogAnalyticsSourceFunction.
        column position


        :return: The lookup_column_position of this LogAnalyticsSourceFunction.
        :rtype: int
        """
        return self._lookup_column_position

    @lookup_column_position.setter
    def lookup_column_position(self, lookup_column_position):
        """
        Sets the lookup_column_position of this LogAnalyticsSourceFunction.
        column position


        :param lookup_column_position: The lookup_column_position of this LogAnalyticsSourceFunction.
        :type: int
        """
        self._lookup_column_position = lookup_column_position

    @property
    def lookup_display_name(self):
        """
        Gets the lookup_display_name of this LogAnalyticsSourceFunction.
        lookup display name


        :return: The lookup_display_name of this LogAnalyticsSourceFunction.
        :rtype: str
        """
        return self._lookup_display_name

    @lookup_display_name.setter
    def lookup_display_name(self, lookup_display_name):
        """
        Sets the lookup_display_name of this LogAnalyticsSourceFunction.
        lookup display name


        :param lookup_display_name: The lookup_display_name of this LogAnalyticsSourceFunction.
        :type: str
        """
        self._lookup_display_name = lookup_display_name

    @property
    def lookup_mode(self):
        """
        Gets the lookup_mode of this LogAnalyticsSourceFunction.
        lookup mode


        :return: The lookup_mode of this LogAnalyticsSourceFunction.
        :rtype: int
        """
        return self._lookup_mode

    @lookup_mode.setter
    def lookup_mode(self, lookup_mode):
        """
        Sets the lookup_mode of this LogAnalyticsSourceFunction.
        lookup mode


        :param lookup_mode: The lookup_mode of this LogAnalyticsSourceFunction.
        :type: int
        """
        self._lookup_mode = lookup_mode

    @property
    def lookup_table(self):
        """
        Gets the lookup_table of this LogAnalyticsSourceFunction.
        lookup table


        :return: The lookup_table of this LogAnalyticsSourceFunction.
        :rtype: str
        """
        return self._lookup_table

    @lookup_table.setter
    def lookup_table(self, lookup_table):
        """
        Sets the lookup_table of this LogAnalyticsSourceFunction.
        lookup table


        :param lookup_table: The lookup_table of this LogAnalyticsSourceFunction.
        :type: str
        """
        self._lookup_table = lookup_table

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsSourceFunction.
        source Id


        :return: The source_id of this LogAnalyticsSourceFunction.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsSourceFunction.
        source Id


        :param source_id: The source_id of this LogAnalyticsSourceFunction.
        :type: int
        """
        self._source_id = source_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
